.. _api:

API
===

.. module:: gntplib


Simple Functions
----------------

.. autofunction:: publish

.. autofunction:: subscribe

Application Objects
-------------------

.. autoclass:: Publisher
   :members:
   :inherited-members:

.. autoclass:: Subscriber
   :members:
   :inherited-members:

.. autoclass:: gntplib.async.AsyncPublisher
   :members:
   :inherited-members:

.. autoclass:: gntplib.async.AsyncSubscriber
   :members:
   :inherited-members:


GNTP Client Object
------------------

.. autoclass:: GNTPClient


Notification Type Object
------------------------

.. autoclass:: Event
   :members:
   :inherited-members:


Resource Objects
----------------

.. autoclass:: Resource
   :members:
   :inherited-members:

.. currentmodule:: gntplib.async
.. autoclass:: AsyncResource
   :members:


Socket Callback Object
----------------------

.. currentmodule:: gntplib
.. autoclass:: SocketCallback
   :members:
   :inherited-members:
